* Costruzione di HY020: reddito totale familiare disponibile (netto);
* Costruzione scala di equivalenza OECD 50-30;


/* CONSTRUCTION of HY020: Total disposable household income (p.111 documento pdf)

The sum for all household members of gross personal income components (gross employee
cash or near cash income (PY010G); gross non-cash employee income (PY021G); gross cash
benefits or losses from self-employment (including royalties) (PY050G); unemployment
benefits (PY090G); old-age benefits (PY100G); survivor' benefits (PY110G), sickness
benefits (PY120G); disability benefits (PY130G) and education-related allowances
(PY140G)) plus gross income components at household level: income from rental of a
property or land (HY040G); family/children related allowances (HY050G); social exclusion
not elsewhere classified (HY060G); housing allowances (HY070G); regular inter-household
cash transfers received (HY080G); interests, dividends, profit from capital investments in
unincorporated business (HY090G); income received by people aged under 16 (HY110G))
minus; regular taxes on wealth (HY120G); regular inter-household cash transfer paid
(HY130G); tax on income and social insurance contributions (HY140G)).
*/

* Step 1a - costruzione del reddito personale;

data pers_inc;set lab_sas.lux_p_file;
pers_inc=sum(PY010G, PY021G, PY050G, PY090G, PY100G, PY110G, PY120G, PY130G, PY140G);
run;

proc univariate data=pers_inc; * Distribuzione su tutti i 16+;
var pers_inc;
weight PB040; * peso di riporto all'universo;
run;

data pers_neg_inc;set pers_inc; * chi sono coloro che hanno redditi personali negativi ?;
where pers_inc lt 0;
run;


proc univariate data=pers_inc; * Distribuzione sui soli percettori di reddito 16+;
var pers_inc;
weight PB040;
where pers_inc ne 0;
run;

* Step 1b - aggregazione del reddito personale a livello familiare;

proc sort data=pers_inc; by PX030;run;
proc univariate data= pers_inc noprint; output out=hh_pers_inc sum=hh_pers_inc;
var pers_inc;
by PX030;*Questo  l'identificativo della famiglia nel P-file;
run;


proc univariate data=hh_pers_inc;
var hh_pers_inc;
run;

* OK 4876 nuclei familiari!!;



* a questo punto dovremmo "attaccare" i redditi pers al file familaire attraverso un "merge";

* conviene prima calcolare la scala di equivelenza HX050 - ovvero la OECD 50-30;

data age_group;set lab_sas.lux_r_file;
if RX020 lt 16 then child=1;else child=0;
if RX020 ge 16 then adult=1;else adult=0;
run;


proc sort data=age_group;by RX030;run;

proc univariate data=age_group noprint; output out=hh_age_group sum=num_child sum=num_adult;
var child adult;
by RX030;
run;

* controllo;

data hh_age_group; set hh_age_group;
hh_size=num_child+num_adult;
run;

proc univariate data=hh_age_group;
var hh_size;
run;

* ok !!!! (somma delle osservazioni = 13423 individui in 4876 nuclei familiari );


proc freq data=hh_age_group;
table hh_size;
run;


data hh_age_group; set hh_age_group;
scala_oecd_50_30=1+0.5*(num_adult-1)+0.3*num_child;
HB030=RX030; * serve per fare il merge - HB030 l'identificativo della famiglia nell' H-file;
run;

proc freq data=hh_age_group;
table scala_oecd_50_30;
run;

data hh_pers_inc;set hh_pers_inc;
HB030=PX030; * serve per fare il merge - HB030 l'identificativo della famiglia nell' H-file;
run;

proc sort data=lab_sas.lux_h_file;by HB030;run;
proc sort data=hh_pers_inc;by HB030;run;
proc sort data=hh_age_group;by HB030;run;

data eq_inc;merge lab_sas.lux_h_file hh_pers_inc hh_age_group;by HB030;
hh_inc=sum ( HY040G, HY050G, HY060G, HY070G, HY080G, HY090G, HY110G);* componenti da sommare;
hh_tax_transf= sum (HY120G, HY130G, HY140G);                         * componenti da sottrarre;
disp_inc=hh_pers_inc+hh_inc-hh_tax_transf;
check=disp_inc-HY020; * controllo che le due variabili siano uguali;
run;

/*
The sum for all household members of gross personal income components (gross employee
cash or near cash income (PY010G); gross non-cash employee income (PY021G); gross cash
benefits or losses from self-employment (including royalties) (PY050G); unemployment
benefits (PY090G); old-age benefits (PY100G); survivor' benefits (PY110G), sickness
benefits (PY120G); disability benefits (PY130G) and education-related allowances
(PY140G)) plus gross income components at household level: income from rental of a
property or land (HY040G); family/children related allowances (HY050G); social exclusion
not elsewhere classified (HY060G); housing allowances (HY070G); regular inter-household
cash transfers received (HY080G); interests, dividends, profit from capital investments in
unincorporated business (HY090G); income received by people aged under 16 (HY110G))
minus; regular taxes on wealth (HY120G); regular inter-household cash transfer paid
(HY130G); tax on income and social insurance contributions (HY140G)).
*/

proc freq data=eq_inc;
table check;
run;

* ok, solo problemi di arrotondamento + o - 1 euro;

* possiamo prendere direttamente la variabile costruita HX090 reddito equivalente;

